@@ -36,7 +36,7 @@ def list_lights(value: bool) -> None:
         for index, info in enumerate(lights):
             typer.secho(f"ID:{'KEY':<16s}:VALUE", fg="blue")
             for key, value in info.items():
-                if not len(str(value)) or key == "path":
+                if not len(str(value)):
                     continue
                 if isinstance(value, int):
                     value = hex(value)
@@ -169,6 +169,19 @@ def blync_callback(
     $ blync throbber
     $ blync rainbow
     ```
+
+
+    Installation
+
+    \b
+    ```console
+    $ python3 -m pip install blynclight
+    $ python3 -m pip install git+https://github.com/JnyJny/blynclight.git # latest
+    ```
+
+    This module depends on [hidapi](https://github.com/libusb/hidapi), which supports
+    Windows, Linux, FreeBSD and MacOS. Check your favorite package managers before
+    attempting to download and build the library from source.
     """
 
     try:
@@ -280,9 +293,9 @@ def throbber_subcommand(
 
     try:
         step = 8 * (min(max(0, fast), 24) + 1)
-        colors = Gradient(0, 255, step, light.red, light.green, light.blue)
-        colors += reversed(colors)
-
+        colors = Gradient(
+            0, 255, step, light.red, light.green, light.blue, reverse=True
+        )
         light.color = (0, 0, 0)
         light.immediate = 1
 
